Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(140)

Unified Diff: src/parsing/parser.h

Issue 2342443004: Only pass the outer scope info with ParseInfo (Closed)
Patch Set: rebase Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/parsing/parse-info.cc ('k') | src/parsing/parser.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/parsing/parser.h
diff --git a/src/parsing/parser.h b/src/parsing/parser.h
index 63100a2a14badf909cec24e332f71c85a7724663..e226e25ae7cd4ae7c32f709a9fd208669c0c5a29 100644
--- a/src/parsing/parser.h
+++ b/src/parsing/parser.h
@@ -186,14 +186,14 @@ class Parser : public ParserBase<Parser> {
// Deserialize the scope chain prior to parsing in which the script is going
// to be executed. If the script is a top-level script, or the scope chain
// consists of only a native context, maybe_context should be an empty
// handle.
//
// This only deserializes the scope chain, but doesn't connect the scopes to
// their corresponding scope infos. Therefore, looking up variables in the
// deserialized scopes is not possible.
void DeserializeScopeChain(ParseInfo* info,
- MaybeHandle<Context> maybe_context);
+ MaybeHandle<ScopeInfo> maybe_outer_scope_info);
// Handle errors detected during parsing, move statistics to Isolate,
// internalize strings (move them to the heap).
« no previous file with comments | « src/parsing/parse-info.cc ('k') | src/parsing/parser.cc » ('j') | no next file with comments »
@@ -186,14 +186,14 @@ class Parser : public ParserBase<Parser> {
// Deserialize the scope chain prior to parsing in which the script is going
// to be executed. If the script is a top-level script, or the scope chain
- // consists of only a native context, maybe_context should be an empty
- // handle.
+ // consists of only a native context, maybe_outer_scope_info should be an
+ // empty handle.
//
// This only deserializes the scope chain, but doesn't connect the scopes to

Powered by Google App Engine
This is Rietveld 408576698